==> tencentcloud-sdk-java-3.1.135-sources.jar: com/tencentcloudapi/vpc/v20170312/models/AccountAttribute.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vpc.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AccountAttribute extends AbstractModel{

    /**
    * 属性名
    */
    @SerializedName("AttributeName")
    @Expose
    private String AttributeName;

    /**
    * 属性值
    */
    @SerializedName("AttributeValues")
    @Expose
    private String [] AttributeValues;

    /**
     * Get 属性名 
     * @return AttributeName 属性名
     */
    public String getAttributeName() {
        return this.AttributeName;
    }

    /**
     * Set 属性名
     * @param AttributeName 属性名
     */
    public void setAttributeName(String AttributeName) {
        this.AttributeName = AttributeName;
    }

    /**
     * Get 属性值 
     * @return AttributeValues 属性值
     */
    public String [] getAttributeValues() {
        return this.AttributeValues;
    }

    /**
     * Set 属性值
     * @param AttributeValues 属性值
     */
    public void setAttributeValues(String [] AttributeValues) {
        this.AttributeValues = AttributeValues;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AttributeName", this.AttributeName);
        this.setParamArraySimple(map, prefix + "AttributeValues.", this.AttributeValues);

    }
}

==> tencentcloud-sdk-java-3.1.607-sources.jar: com/tencentcloudapi/vpc/v20170312/models/AccountAttribute.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.vpc.v20170312.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class AccountAttribute extends AbstractModel{

    /**
    * 属性名
    */
    @SerializedName("AttributeName")
    @Expose
    private String AttributeName;

    /**
    * 属性值
    */
    @SerializedName("AttributeValues")
    @Expose
    private String [] AttributeValues;

    /**
     * Get 属性名 
     * @return AttributeName 属性名
     */
    public String getAttributeName() {
        return this.AttributeName;
    }

    /**
     * Set 属性名
     * @param AttributeName 属性名
     */
    public void setAttributeName(String AttributeName) {
        this.AttributeName = AttributeName;
    }

    /**
     * Get 属性值 
     * @return AttributeValues 属性值
     */
    public String [] getAttributeValues() {
        return this.AttributeValues;
    }

    /**
     * Set 属性值
     * @param AttributeValues 属性值
     */
    public void setAttributeValues(String [] AttributeValues) {
        this.AttributeValues = AttributeValues;
    }

    public AccountAttribute() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public AccountAttribute(AccountAttribute source) {
        if (source.AttributeName != null) {
            this.AttributeName = new String(source.AttributeName);
        }
        if (source.AttributeValues != null) {
            this.AttributeValues = new String[source.AttributeValues.length];
            for (int i = 0; i < source.AttributeValues.length; i++) {
                this.AttributeValues[i] = new String(source.AttributeValues[i]);
            }
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AttributeName", this.AttributeName);
        this.setParamArraySimple(map, prefix + "AttributeValues.", this.AttributeValues);

    }
}
